# PROCESSADOR DE IMAGEM VIRTUAL

Description. 

O processamento da imagem do pacote e usado para:
	
	Em processamento:
		- Correspondencia de histograma
		- Semelhanca estrutural
		- Redimensionar imagem
	
	Util:
		- Ler imagem
		- Salvar imagem
		- Plotar imagem
		- Resultado da trama
		- Plotar histograma

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name



```bash
pip install image_processing
```

## Usage

```python
from package_name import file1_name
file1_name.my_function()
```

## Author
Jair Pereira

## License
[MIT](https://choosealicense.com/licenses/mit/)
